==> e107-0.7.20.tbz: www/e107/e107_languages/English/admin/lan_mailout.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/admin/lan_mailout.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PRFLAN_52", "Save Changes");
define("PRFLAN_63", "Send test email");
//define("PRFLAN_64", "Clicking button will send test email to main admin email address");
define("PRFLAN_65", "Click to send email to");
define("PRFLAN_66", "Test email from");
define("PRFLAN_67", "This is a test email, it appears that your email settings are working ok!\n\nRegards\nfrom the e107 website system.");
define("PRFLAN_68", "The email could not be sent. It appears that your server is not correctly configured to send emails, please try again using SMTP, or contact your hosts and ask them to check their sendmail / email server settings.");
define("PRFLAN_69", "The email has been successfully sent, please check your inbox.");
define("PRFLAN_70", "Emailing method");
define("PRFLAN_71", "If unsure, leave as php");
define("PRFLAN_72", "SMTP Server");
define("PRFLAN_73", "SMTP Username");
define("PRFLAN_74", "SMTP Password");
define("PRFLAN_75", "The email could not be sent. Please review your SMTP settings, or disable SMTP and try again.");

define("MAILAN_01","From Name");
define("MAILAN_02","From Email");
define("MAILAN_03","To");
define("MAILAN_04","Cc");
define("MAILAN_05","Bcc");
define("MAILAN_06","Subject");
define("MAILAN_07","Attachment");
define("MAILAN_08","Send Email");
define("MAILAN_09","Use Theme Style");
define("MAILAN_10","User Subscribed");
define("MAILAN_11","Insert Variables");
define("MAILAN_12","All Members");
define("MAILAN_13","All Unverified Members ");
define("MAILAN_14","It is recommended that you enable SMTP for sending large numbers of emails - set in preferences below.");
define("MAILAN_15","Mail-Out");

define("MAILAN_16","username");
define("MAILAN_17","signup link");
define("MAILAN_18","user id");
define("MAILAN_19","There is no email address for site-admin. Please check your preferences and try again.");
define("MAILAN_20","Sendmail-path");
define("MAILAN_21","Mass-Mail Entries");
define("MAILAN_22","There are currently no saved entries");
define("MAILAN_23","userclass: ");
define("MAILAN_24", "email(s) are ready to be sent");

define("MAILAN_25", "Pause");
define("MAILAN_26", "Pause mass-mailing every");
define("MAILAN_27", "emails");
define("MAILAN_28", "Pause Length");
define("MAILAN_29", "seconds");
define("MAILAN_30", "More than 30 seconds may cause the browser to time-out");
define("MAILAN_31", "Bounced Email Processing");
define("MAILAN_32", "Email address");
define("MAILAN_33", "Incoming Mail");
define("MAILAN_34", "Account Name");
define("MAILAN_35", "Password");
define("MAILAN_36", "Delete Bounced Mails after checking");

define("MAILAN_37", "Proceed");
define("MAILAN_38", "Cancel");
define("MAILAN_39", "Emailing");
define("MAILAN_40", "You need to rename <b>e107.htaccess</b> to <b>.htaccess</b> in");
define("MAILAN_41", "before sending mail from this page.");
define("MAILAN_42", "Warning");
define("MAILAN_43", "Username");
define("MAILAN_44", "User Login");
define("MAILAN_45", "User Email");
define("MAILAN_46", "User-Match");
define("MAILAN_47", "contains");
define("MAILAN_48", "equals");
define("MAILAN_49", "Id");
define("MAILAN_50", "Author");
define("MAILAN_51", "Subject");
define("MAILAN_52", "Lastmod");
define("MAILAN_53", "Admins");
define("MAILAN_54", "Self");
define("MAILAN_55", "Userclass");
define("MAILAN_56", "Send Mail");
define("MAILAN_57", "Keep SMTP session alive");
define("MAILAN_58", "There is a problem with the attachment:");
define("MAILAN_59", "Mailing Progress");
define("MAILAN_60", "Sending...");
define("MAILAN_61", "There are no remaining emails to be sent.");
define("MAILAN_62", "Emails sent:");
define("MAILAN_63", "Emails failed:");
define("MAILAN_64", "Total time elapsed:");
define("MAILAN_65", "seconds");
define("MAILAN_66", "Cancelled Successfully");
define("MAILAN_67", "Use 'POP before SMTP' authentication"); 
define('MAILAN_68', 'Test address');






?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/admin/lan_mailout.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/admin/lan_mailout.php $
|     $Revision: 12180 $
|     $Id: lan_mailout.php 12180 2011-05-02 21:09:45Z e107steved $
|     $Author: e107steved $
+----------------------------------------------------------------------------+
*/
define("PRFLAN_52", "Save Changes");
define("PRFLAN_63", "Send test email");
//define("PRFLAN_64", "Clicking button will send test email to main admin email address");
define("PRFLAN_65", "Click to send email to");
define("PRFLAN_66", "Test email from");
define("PRFLAN_67", "This is a test email, it appears that your email settings are working ok!\n\nRegards\nfrom the e107 website system.");
define("PRFLAN_68", "The email could not be sent. It appears that your server is not correctly configured to send emails, please try again using SMTP, or contact your hosts and ask them to check their sendmail / email server settings.");
define("PRFLAN_69", "The email has been successfully sent, please check your inbox.");
define("PRFLAN_70", "Emailing method");
define("PRFLAN_71", "If unsure, leave as php");
define("PRFLAN_72", "SMTP Server");
define("PRFLAN_73", "SMTP Username");
define("PRFLAN_74", "SMTP Password");
define("PRFLAN_75", "The email could not be sent. Please review your SMTP settings, or disable SMTP and try again.");

define("MAILAN_01","From Name");
define("MAILAN_02","From Email");
define("MAILAN_03","To");
define("MAILAN_04","Cc");
define("MAILAN_05","Bcc");
define("MAILAN_06","Subject");
define("MAILAN_07","Attachment");
define("MAILAN_08","Send Email");
define("MAILAN_09","Use Theme Style");
define("MAILAN_10","User Subscribed");
define("MAILAN_11","Insert Variables");
define("MAILAN_12","All Members");
define("MAILAN_13","All Unverified Members ");
define("MAILAN_14","It is recommended that you enable SMTP for sending large numbers of emails - set in preferences below.");
define("MAILAN_15","Mail-Out");

define("MAILAN_16","username");
define("MAILAN_17","signup link");
define("MAILAN_18","user id");
define("MAILAN_19","There is no email address for site-admin. Please check your preferences and try again.");
define("MAILAN_20","Sendmail-path");
define("MAILAN_21","Mass-Mail Entries");
define("MAILAN_22","There are currently no saved entries");
define("MAILAN_23","userclass: ");
define("MAILAN_24", "email(s) are ready to be sent");

define("MAILAN_25", "Pause");
define("MAILAN_26", "Pause mass-mailing every");
define("MAILAN_27", "emails");
define("MAILAN_28", "Pause Length");
define("MAILAN_29", "seconds");
define("MAILAN_30", "More than 30 seconds may cause the browser to time-out");
define("MAILAN_31", "Bounced Email Processing");
define("MAILAN_32", "Email address");
define("MAILAN_33", "Incoming Mail");
define("MAILAN_34", "Account Name");
define("MAILAN_35", "Password");
define("MAILAN_36", "Delete Bounced Mails after checking");

define("MAILAN_37", "Proceed");
define("MAILAN_38", "Cancel");
define("MAILAN_39", "Emailing");
define("MAILAN_40", "You need to rename <b>e107.htaccess</b> to <b>.htaccess</b> in");
define("MAILAN_41", "before sending mail from this page.");
define("MAILAN_42", "Warning");
define("MAILAN_43", "Username");
define("MAILAN_44", "User Login");
define("MAILAN_45", "User Email");
define("MAILAN_46", "User-Match");
define("MAILAN_47", "contains");
define("MAILAN_48", "equals");
define("MAILAN_49", "Id");
define("MAILAN_50", "Author");
define("MAILAN_51", "Subject");
define("MAILAN_52", "Lastmod");
define("MAILAN_53", "Admins");
define("MAILAN_54", "Self");
define("MAILAN_55", "Userclass");
define("MAILAN_56", "Send Mail");
define("MAILAN_57", "Keep SMTP session alive");
define("MAILAN_58", "There is a problem with the attachment:");
define("MAILAN_59", "Mailing Progress");
define("MAILAN_60", "Sending...");
define("MAILAN_61", "There are no remaining emails to be sent.");
define("MAILAN_62", "Emails sent:");
define("MAILAN_63", "Emails failed:");
define("MAILAN_64", "Total time elapsed:");
define("MAILAN_65", "seconds");
define("MAILAN_66", "Cancelled Successfully");
define("MAILAN_67", "Use 'POP before SMTP' authentication"); 
define('MAILAN_68', 'Test address');
define("MAILAN_69","user login");
define("MAILAN_70","user email");



?>
